@@ -2,8 +2,8 @@ from .DataViewer import *
 
 from .Image2D import *
 from .Spec1D import *
-from .Eazy import *
 
-from .ControlPanel import *
+from .ControlBar import *
+from .QuickSearch import *
 from .ObjectInfo import *
 from .ReviewForm import *
